@@ -1311,7 +1311,7 @@ class StartOnlineRecordRequest(AbstractModel):
         :type SdkAppId: int
         :param RoomId: 需要录制的房间号，取值范围: (1, 4294967295)
         :type RoomId: int
-        :param RecordUserId: 用于录制服务进房的用户ID，格式为`tic_record_user_${RoomId}_${Random}`，其中 `${RoomId} `与录制房间号对应，`${Random}`为一个随机字符串。
+        :param RecordUserId: 用于录制服务进房的用户ID，最大长度不能大于60个字节，格式为`tic_record_user_${RoomId}_${Random}`，其中 `${RoomId} `与录制房间号对应，`${Random}`为一个随机字符串。
 该ID必须是一个单独的未在SDK中使用的ID，录制服务使用这个用户ID进入房间进行音视频与白板录制，若该ID和SDK中使用的ID重复，会导致SDK和录制服务互踢，影响正常录制。
         :type RecordUserId: str
         :param RecordUserSig: 与RecordUserId对应的签名
@@ -1344,7 +1344,11 @@ VIDEO_GENERATION_MODE - 视频生成模式（内测中，需邮件申请开通
 
 在`视频生成模式`下，默认会记录白板群组内的非白板信令消息，如果指定了`ChatGroupId`，则会记录指定群ID的聊天消息。
         :type ChatGroupId: str
-        :param ExtraData: 内部参数
+        :param AutoStopTimeout: 自动停止录制超时时间，单位秒，取值范围[300, 86400], 默认值为300秒。
+
+当超过设定时间房间内没有音视频上行且没有白板操作的时候，录制服务会自动停止当前录制任务。
+        :type AutoStopTimeout: int
+        :param ExtraData: 内部参数，可忽略
         :type ExtraData: str
         """
         self.SdkAppId = None
@@ -1360,6 +1364,7 @@ VIDEO_GENERATION_MODE - 视频生成模式（内测中，需邮件申请开通
         self.RecordControl = None
         self.RecordMode = None
         self.ChatGroupId = None
+        self.AutoStopTimeout = None
         self.ExtraData = None
 
 
@@ -1385,6 +1390,7 @@ VIDEO_GENERATION_MODE - 视频生成模式（内测中，需邮件申请开通
             self.RecordControl._deserialize(params.get("RecordControl"))
         self.RecordMode = params.get("RecordMode")
         self.ChatGroupId = params.get("ChatGroupId")
+        self.AutoStopTimeout = params.get("AutoStopTimeout")
         self.ExtraData = params.get("ExtraData")
 
 
@@ -1420,8 +1426,7 @@ class StartWhiteboardPushRequest(AbstractModel):
         :type SdkAppId: int
         :param RoomId: 需要推流白板的房间号，取值范围: (1, 4294967295)
         :type RoomId: int
-        :param PushUserId: 用于白板推流服务进房进行推流的用户ID，
-该ID必须是一个单独的未在SDK中使用的ID，白板推流服务使用这个用户ID进入房间进行白板音视频推流，若该ID和SDK中使用的ID重复，会导致SDK和白板推流服务互踢，影响正常推流。
+        :param PushUserId: 用于白板推流服务进房进行推流的用户ID，最大长度不能大于60个字节，该ID必须是一个单独的未在SDK中使用的ID，白板推流服务使用这个用户ID进入房间进行白板音视频推流，若该ID和SDK中使用的ID重复，会导致SDK和白板推流服务互踢，影响正常推流。
         :type PushUserId: str
         :param PushUserSig: 与PushUserId对应的签名
         :type PushUserSig: str
